@@ -2,10 +2,11 @@ package DBIx::DataModel::Meta::Source::Join;
 use strict;
 use warnings;
 use Params::Validate qw/HASHREF ARRAYREF/;
-use namespace::autoclean;
 
 use parent "DBIx::DataModel::Meta::Source";
 
+use namespace::clean;
+
 sub new {
   my $class = shift;
 
